@@ -1,3 +1,19 @@
+"""
+Copyright Astronomer, Inc.
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+"""
+
 import os
 from typing import Optional
 from urllib.parse import urlparse
@@ -6,9 +22,9 @@ import pandas as pd
 from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator, DagRun, TaskInstance
 
+from astro.sql.table import Table
 from astro.utils.load_dataframe import move_dataframe_to_sql
 from astro.utils.task_id_helper import get_task_id
-from astro.sql.table import Table
 
 
 class AgnosticLoadFile(BaseOperator):
@@ -27,7 +43,7 @@ class AgnosticLoadFile(BaseOperator):
     def __init__(
         self,
         path="",
-        output_table: Table =None,
+        output_table: Table = None,
         file_conn_id="",
         chunksize=None,
         **kwargs,
@@ -112,10 +128,6 @@ def load_file(
     path,
     output_table=None,
     file_conn_id=None,
-    output_conn_id=None,
-    database=None,
-    schema=None,
-    warehouse=None,
     task_id=None,
     **kwargs,
 ):
@@ -125,12 +137,10 @@ def load_file(
 
     :param path: File path.
     :type path: str
-    :param output_table_name: Name of table to create.
-    :type output_table_name: str
+    :param output_table: Table to create
+    :type output_table: Table
     :param file_conn_id: Airflow connection id of input file (optional)
     :type file_conn_id: str
-    :param output_conn_id: Database connection id.
-    :type output_conn_id: str
     :param task_id: task id, optional.
     :type task_id: str
     """
